import PageContent from '@/components/PageContent';
import PageTitle from '@/components/PageTitle';
import { GetTokenFromUrl, UnityAction } from '@/utils/utils';
import { connect, history, useParams } from '@umijs/max';
import { Table } from 'antd';
import dayjs from 'dayjs';
import { Fragment, useEffect } from 'react';

function List(props) {
  const { loading, list, processList = [], dispatch } = props;

  const { projectId } = useParams();

  const getColumns = () => {
    return [
      {
        title: '自检时间',
        dataIndex: 'CreatedTime',
        width: '26%',
        render: (text) => {
          return text ? dayjs(text).format('YYYY-MM-DD HH:mm') : null;
        },
      },
      {
        title: '工艺段',
        width: '24%',
        render: (record) => {
          const name = processList?.find(
            (item) => item.group_id == record?.RouteInfo?.GroupID,
          )?.name;
          return name || '-';
        },
      },
      {
        title: '状态',
        width: '10%',
        dataIndex: 'Status',
        render: (text) => {
          return text == 0 ? (
            '正常'
          ) : (
            <div style={{ color: '#FF8600' }}>异常</div>
          );
        },
      },
      {
        title: '操作',
        width: '16%',
        render: (text, record) => {
          return (
            <Fragment>
              {
                <>
                  <a
                    onClick={(e) => {
                      goToDetail(record, e);
                    }}
                  >
                    详情
                  </a>
                </>
              }
            </Fragment>
          );
        },
      },
    ];
  };

  const goToDetail = (record, e) => {
    e.stopPropagation();
    UnityAction.sendMsg('reportDetail', '');
    history.push(
      `/self-inspection/detail/${projectId}/${
        record.Id
      }?JWT-TOKEN=${GetTokenFromUrl()}`,
    );
  };

  useEffect(() => {
    let params = {};
    params.projectId = projectId;
    params.auto = 1;
    params.startDate = dayjs().subtract(1).format('YYYY-MM-DD');
    params.endDate = dayjs().format('YYYY-MM-DD');
    params.pageSize = 100;
    params.currentPage = 1;
    dispatch({
      type: 'patrolArtificialRecord/queryPatrol',
      payload: params,
    });
  }, []);
  return (
    <PageContent closeable={false}>
      <PageTitle returnable>自检记录</PageTitle>

      <Table
        bordered
        loading={loading}
        columns={getColumns()}
        dataSource={list}
      />
    </PageContent>
  );
}

export default connect(({ patrolArtificialRecord, loading }) => ({
  list: patrolArtificialRecord.list,
  routeInfoList: patrolArtificialRecord.routeInfoList,
  loading: loading.models.patrolArtificialRecord,
  processList: patrolArtificialRecord.processList,
}))(List);
